<?php

namespace App\Http\Controllers;

use App\Models\Afiliado;
use App\Http\Requests\StoreAfiliadoRequest;
use App\Http\Requests\UpdateAfiliadoRequest;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use GuzzleHttp\Client;

class AfiliadoController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('afiliado.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */


    public function store(StoreAfiliadoRequest $request)
    {
        // Validación
        $validator = Validator::make(
            $request->all(),
            [
                'nombres' => 'required|string|max:50',
                'apellidos' => 'required|string|max:50',
                'correo' => 'required|email|unique:users,email',
                'password' => 'required|string|min:6',
                'cedula' => 'required|numeric|unique:afiliados,cedula',
                'direccion' => 'required',
                'foto' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048'
            ],
            [
                'correo.required' => 'El Correo es obligatorio',
                'correo.unique' => 'El Correo ya está registrado',
                'correo.email' => 'No tiene un formato válido',
                'nombres.required' => 'Campo Nombres es Requerido',
                'nombres.min' => 'Campo Nombres requiere 5 caracteres mínimo',
                'nombres.max' => 'Campo Nombres no puede exceder 50 caracteres',

                'apellidos.required' => 'Campo Apellidos es Requerido',
                'apellidos.min' => 'Campo Apellidos requiere 5 caracteres mínimo',
                'apellidos.max' => 'Campo Apellidos no puede exceder 50 caracteres',

                'telefono.required' => 'Campo Teléfono es Requerido',
                'telefono.numeric' => 'El campo Teléfono debe ser numérico',
                'telefono.digits' => 'Campo Teléfono requiere 11 caracteres',

                'direccion.required' => 'Campo Dirección es Requerido',
                'direccion.min' => 'Campo Dirección requiere 5 caracteres mínimo',
                'direccion.max' => 'Campo Dirección no puede exceder los 200 caracteres',

                'cedula.required' => 'Campo Cédula es Requerido',
                'cedula.unique' => 'La cédula debe ser única',

                'foto.image' => 'El archivo debe ser una imagen',
                'foto.mimes' => 'La imagen debe ser un archivo de tipo: jpeg, png, jpg, gif',
                'foto.max' => 'La imagen no puede superar los 2 MB'
            ]
        );

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        // Subida de imagen a Imgur
        $foto = null;
        if ($request->file('foto')) {
            $imagen_name = $request->file('foto')->getClientOriginalName();
            $imagen_path = $request->file('foto')->getPathname();
            $imagen_mime = $request->file('foto')->getMimeType();
            $client = new Client();

            $response = $client->post('https://api.imgur.com/3/upload', [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ],
                'multipart' => [
                    [
                        'name' => 'image',
                        'filename' => $imagen_name,
                        'Mime-Type' => $imagen_mime,
                        'contents' => fopen($imagen_path, 'r'),
                    ]
                ]
            ]);

            $foto = json_decode($response->getBody()->getContents())->data->link;
        }

        // Crear el usuario
        $user = User::create([
            'name' => $request->nombres,
            'email' => $request->correo,
            'password' => Hash::make($request->password),
        ]);

        // Crear el afiliado asociado al usuario
        $afiliado = new Afiliado([
            'nombres' => $request->nombres,
            'apellidos' => $request->apellidos,
            'cedula' => $request->cedula,
            'telefono' => $request->telefono,
            'direccion' => $request->direccion,
            'estatus' => 1,
            'foto' => $foto
        ]);

        $afiliado->user()->associate($user);
        $afiliado->save();

        return response()->json(['mensaje' => 'Afiliado creado exitosamente', 'afiliado' => $afiliado]);
    }



    /**
     * Display the specified resource.
     */
    public function show($idAfiliado)
    {
        // Usamos with('user') para cargar la relación user
        $afiliado = Afiliado::with('user')->findOrFail($idAfiliado);
        return view('afiliado.perfil', compact('afiliado'));
    }



    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request)
    {
        $idAfiliado = $request->input('idRegistroParaEditar');
        $afiliado = Afiliado::findOrFail($idAfiliado);
        return response()->json($afiliado);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(UpdateAfiliadoRequest $request)
    {


        $idAfiliado = $request->input('idAfiliadoEdicion');
        $validator = Validator::make(
            $request->all(),
            [
                'nombresEdit' => 'required|string|min:5|max:50',
                'apellidosEdit' => 'required|string|max:50',
                'direccionEdit' => 'required',
                'fotoEdit' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
                'telefonoEdit' => 'numeric|digits:11',
                'cedulaEdit' => ['required', 'numeric', Rule::unique('afiliados', 'cedula')->ignore($idAfiliado),],
            ],
            [

                'nombresEdit.required' => 'Campo Nombres es Requerido',
                'nombresEdit.min' => 'Campo Nombres requiere 5 caracteres mínimo',
                'nombresEdit.max' => 'Campo Nombres no puede exceder 50 caracteres',

                'apellidosEdit.required' => 'Campo Apellidos es Requerido',
                'apellidosEdit.min' => 'Campo Apellidos requiere 5 caracteres mínimo',
                'apellidosEdit.max' => 'Campo Apellidos no puede exceder 50 caracteres',

                'telefonoEdit.required' => 'Campo Teléfono es Requerido',
                'telefonoEdit.numeric' => 'El campo Teléfono debe ser numérico',
                'telefonoEdit.digits' => 'Campo Teléfono requiere 11 caracteres',

                'direccionEdit.required' => 'Campo Dirección es Requerido',
                'direccionEdit.min' => 'Campo Dirección requiere 5 caracteres mínimo',
                'direccionEdit.max' => 'Campo Dirección no puede exceder los 200 caracteres',

                'cedulaEdit.required' => 'Campo Cedula es Requerido',
                'cedulaEdit.unique' => 'La cedula debe ser único'
            ]
        );

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        $foto = null;
        if ($request->file('fotoEdit')) {
            $imagen_name = $request->file('fotoEdit')->getClientOriginalName();
            $imagen_path = $request->file('fotoEdit')->getPathname();
            $imagen_mime = $request->file('fotoEdit')->getMimeType();
            $client = new Client();

            $response = $client->post('https://api.imgur.com/3/upload', [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ],
                'multipart' => [
                    [
                        'name' => 'image',
                        'filename' => $imagen_name,
                        'Mime-Type' => $imagen_mime,
                        'contents' => fopen($imagen_path, 'r'),
                    ]
                ]
            ]);

            $foto = json_decode($response->getBody()->getContents())->data->link;
        }

        // Encontrar el afiliado y actualizar los datos
        $afiliado = Afiliado::findOrFail($idAfiliado);
        $afiliado->nombres = $request->input('nombresEdit');
        $afiliado->apellidos = $request->input('apellidosEdit');
        $afiliado->telefono = $request->input('telefonoEdit');
        $afiliado->direccion = $request->input('direccionEdit');
        $afiliado->cedula = $request->input('cedulaEdit');
        $afiliado->foto = $foto;
        $afiliado->save();

        return response()->json(['mensaje' => 'Afiliado actualizado exitosamente.']);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Afiliado $afiliado)
    {
        //
    }

    private function validacionesYProcesos(Request $request)
    {
        $request->validate([
            'nombre_sucursal' => 'required|min:5|max:50',
            'telefono' => 'required|numeric|digits:11',
            'direccion' => 'required|min:5|max:200',
            'codigo_sucursal' => [
                'required',
                Rule::unique('sucursales', 'codigo_sucursal')
            ],
        ], [
            'nombre_sucursal.min' => 'El nombre de la Sucursal requiere 5 caracteres mínimo',
            'nombre_sucursal.max' => 'El nombre de la Sucursal no puede exceder 50 caracteres',
            'nombre_sucursal.required' => 'Campo Nombre de la Sucursal es Requerido',

            'telefono.required' => 'Campo Teléfono Local es Requerido',
            'telefono.numeric' => 'El campo Teléfono debe ser numérico',
            'telefono.digits' => 'Campo Teléfono local requiere 11 caracteres',

            'direccion.required' => 'Campo Dirección es Requerido',
            'direccion.min' => 'Campo Dirección requiere 5 caracteres mínimo',
            'direccion.max' => 'Campo Dirección no puede exceder los 200 caracteres',

            'codigo_sucursal.required' => 'Campo Código es Requerido',
            'codigo_sucursal.unique' => 'El Código de la Sucursal debe ser único'
        ]);

        $data = $request->only(['nombre_sucursal', 'codigo_sucursal', 'telefono', 'direccion']);

        return $data;
    }

    public function obtenerAfiliados()
    {
        $routeName = 'afiliado'; // Puedes modificar esto según el módulo
        $afiliados = Afiliado::all()->map(function ($datosDelObjeto) use ($routeName) {
            return [
                'id'                => $datosDelObjeto->id,
                'nombres'           => $datosDelObjeto->nombres,
                'apellidos'         => $datosDelObjeto->apellidos,
                'telefono'          => $datosDelObjeto->telefono,
                'direccion'         => $datosDelObjeto->direccion,
                'cedula'            => $datosDelObjeto->cedula,
                'estatus'           => $datosDelObjeto->estatus,
                'correo'            => $datosDelObjeto->user->email,
                'foto'              => $datosDelObjeto->foto,
                'acciones'          => view('components.accionesFormulario', compact('datosDelObjeto', 'routeName'))->render(),

            ];
        });
        return response()->json($afiliados);
    }



    public function cambiarEstatus(Request $request)
    {
        $idAfiliado = $request->input('idRegistroParaEditar');
        $afiliado = Afiliado::findOrFail($idAfiliado);
        $nuevoEstatus = $afiliado->estatus === 'activo' ? 'inactivo' : 'activo';

        $afiliado->estatus = $nuevoEstatus;
        $afiliado->save();
        $estatusMensaje = $afiliado->estatus === 'activo' ? 'Habilitado' : 'Inhabilitada';

        return response()->json(['mensaje' => 'Estatus del afiliado actualizado exitosamente.', 'nuevoEstatus' => $estatusMensaje]);
    }
}
