<?php

namespace App\Http\Controllers;

use App\Models\Empresa;
use App\Http\Requests\StoreEmpresaRequest;
use App\Http\Requests\UpdateEmpresaRequest;
use Illuminate\Http\Request;
use GuzzleHttp\Client;

class EmpresaController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {

        $empresa = Empresa::find(1);

        if ($empresa) {
            return view('empresa.index', compact('empresa'));
        } else {
            return view('empresa.index');
        }
    }

    private function validacionesYProcesos(Request $request)
    {
        $validated = $request->validate([
            'nombre_empresa' => 'required|min:5|max:50',
            'email' => 'required|string|email',
            'telefono' => 'required|numeric|min_digits:11|max_digits:11',
            'direccion' => 'required|min:5|max:200',
            'rif' => 'required',
            'logo' => 'image|mimes:jpg,jpeg,png,gif,svg|max:2048'
        ], [
            'logo.max' => 'La Imagen solo puede tener un máximo de 2 Mb',
            'logo.mimes' => 'Los Formatos Permitidos son Jpg,Jpeg,Png,Svg,Gif',
            'nombre_empresa.min' => 'El nombre de la empresa requiere 5 caracteres mínimo',
            'nombre_empresa.max' => 'El nombre de la empresa no puede exceder 50 caracteres',
            'nombre_empresa.required' => 'Campo Nombre de la empresa es Requerido',
            'email.required' => 'Campo Email es Requerido',
            'email.email' => 'Formato Email Incorrecto, Tenga como referencia ejemplo@ejemplo.com',
            'telefono.required' => 'Campo Teléfono Local es Requerido',
            'telefono.min_digits' => 'Campo Teléfono local requiere 8 caracteres mínimo',
            'telefono.max_digits' => 'Campo Teléfono local no puede exceder 8 caracteres',
            'direccion.required' => 'Campo Dirección es Requerido',
            'direccion.max' => 'Campo Dirección no puede exceder los 200 caracteres',
            'direccion.min' => 'Campo Dirección requiere 15 caracteres mínimo',
            'rif.required' => 'Campo Rif es Requerido',
            'logo.required' => 'Se Debe seleccionar una imagen.'
        ]);

        $data = $request->only(['nombre_empresa', 'email', 'telefono', 'direccion', 'rif', 'logo']);

        if ($request->file('logo')) {
            $imagen_name = $request->file('logo')->getClientOriginalName();
            $imagen_path = $request->file('logo')->getPathname();
            $imagen_mime = $request->file('logo')->getMimeType();
            $client = new Client();

            $response = $client->post('https://api.imgur.com/3/upload', [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ],
                'multipart' => [
                    [
                        'name' => 'image',
                        'filename' => $imagen_name,
                        'Mime-Type' => $imagen_mime,
                        'contents' => fopen($imagen_path, 'r'),
                    ]
                ]
            ]);

            $logoEmpresa = json_decode($response->getBody()->getContents())->data->link;
            $data['logo'] = $logoEmpresa;
        }

        return $data;
    }


    public function store(StoreEmpresaRequest $request)
    {
        $data = $this->validacionesYProcesos($request);
        Empresa::create($data);
        $mensaje = "Registro Exitoso.!";
        return redirect('empresa')->with('registro_exitoso', $mensaje);
    }


    public function update(UpdateEmpresaRequest $request, Empresa $empresa)
    {

        $data = $this->validacionesYProcesos($request);
        $empresa->update($data);
        $mensaje = "Actualización Exitosa.!";
        return redirect('empresa')->with('actualizacion', $mensaje);
    }


}
