<?php

namespace App\Http\Controllers;

use App\Models\Producto;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use App\Models\Almacen;
use App\Models\Proveedor;
use App\Models\Categoria;
use App\Models\Afiliado;
use Illuminate\Support\Facades\Auth;
use GuzzleHttp\Client;
use App\Models\ImagenProducto;


class ProductoController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $almacenes = Almacen::where('estatus', 'activo')->get(['id', 'nombre_almacen']);
        $proveedores = Proveedor::where('estatus', 'activo')->get(['id', 'nombres', 'apellidos']);
        $categorias = Categoria::where('estatus', 'activo')->get(['id', 'nombre_categoria']);
        return view('producto.index', compact('almacenes', 'proveedores', 'categorias'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */

    // Controlador para registrar producto
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'nombre_producto'           => 'required|string|max:255|unique:productos,nombre_producto',
            'descripcion'               => 'nullable|string',
            'sku'                       => 'required|string|unique:productos,sku',
            'categoria_id'              => 'required|exists:categorias,id',
            'subcategoria_id'           => 'required|exists:subcategorias,id',
            'almacen_id'                => 'required|exists:almacenes,id',
            'proveedor_id'              => 'required|exists:proveedores,id',
            'fecha_caducidad'           => 'nullable|date',
            'precio_compra'             => 'required|numeric|min:0',
            'precio_venta'              => 'required|numeric|min:0',
            'precio_maximo_vendedor'    => 'required|numeric|min:0',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }
        $user = Auth::user();

        $producto = Producto::create([
            'nombre_producto' => $request->nombre_producto,
            'descripcion' => $request->descripcion,
            'sku' => $request->sku,
            'precio_compra' => $request->precio_compra,
            'precio_venta' => $request->precio_venta,
            'precio_maximo_vendedor' => $request->precio_maximo_vendedor,
            'categoria_id' => $request->categoria_id,
            'almacen_id' => $request->almacen_id,
            'proveedor_id' => $request->proveedor_id,
            'fecha_caducidad' => $request->fecha_caducidad,
            'creado_por' => $user->id,
            'id_subcategoria' => $request->subcategoria_id


        ]);

        return response()->json(['mensaje' => 'Producto creado exitosamente', 'producto' => $producto], 201);
    }

    /**
     * Display the specified resource.
     */
    public function show(Producto $producto)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request)
    {
        $idProducto = $request->input('idRegistroParaEditar');
        $dataProducto = Producto::findOrFail($idProducto);
        return response()->json($dataProducto);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Producto $producto)
    {
        // Validación
        $idProducto = $request->input('idProductoEdicion');
        $validator = Validator::make($request->all(), [
            'nombre_producto'           => 'required|string|max:255|unique:productos,nombre_producto,' . $idProducto,
            'descripcion'               => 'nullable|string',
            'sku'                       => 'required|string|unique:productos,sku,' . $idProducto,
            'categoria_id'              => 'required|exists:categorias,id',
            'almacen_id'                => 'required|exists:almacenes,id',
            'proveedor_id'              => 'required|exists:proveedores,id',
            'fecha_caducidad'           => 'nullable|date',
            'precio_compra'             => 'required|numeric|min:0',
            'precio_venta'              => 'required|numeric|min:0',
            'precio_maximo_vendedor'    => 'required|numeric|min:0',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);

            try {
                // Encontrar el almacén existente
                $producto = Producto::findOrFail($idProducto);
                $producto->update([
                    'nombre_producto' => $request->nombre_producto,
                    'descripcion' => $request->descripcion,
                    'sku' => $request->sku,
                    'precio_compra' => $request->precio_compra,
                    'precio_venta' => $request->precio_venta,
                    'precio_maximo_vendedor' => $request->precio_maximo_vendedor,
                    'categoria_id' => $request->categoria_id,
                    'almacen_id' => $request->almacen_id,
                    'proveedor_id' => $request->proveedor_id,
                    'fecha_caducidad' => $request->fecha_caducidad,
                ]);

                return response()->json(['mensaje' => 'Producto actualizado exitosamente', 'producto' => $producto], 200);
            } catch (\Exception $e) {
                // Loguear el error para depuración
                Log::error('Error al actualizar el producto: ' . $e->getMessage());

                // Retornar respuesta de error genérico
                return response()->json(['mensaje' => 'Ocurrió un error al actualizar el Producto.'], 500);
            }
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Producto $producto)
    {
        //
    }

    public function obtenerProductos()
    {
        $routeName = 'productos'; // Puedes modificar esto según el módulo
        $productos = Producto::All()->map(function ($datosDelObjeto) use ($routeName) {
            return [
                'id'                => $datosDelObjeto->id,
                'nombre'            => $datosDelObjeto->nombre_producto,
                'descripcion'       => $datosDelObjeto->descripcion,
                'estatus'           => $datosDelObjeto->estatus,
                'proveedor'         => $datosDelObjeto->proveedor->nombres . ' ' . $datosDelObjeto->proveedor->apellidos,
                'categoria'           => $datosDelObjeto->categoria->nombre_categoria,
                'precio_compra'          => $datosDelObjeto->precio_compra,
                'cantArticulos'     => $datosDelObjeto->cantidad,
                'imagen'            => $datosDelObjeto->imagenPrincipal ? $datosDelObjeto->imagenPrincipal->url_imagen : null,
                'acciones'          => view('components.accionesFormulario', compact('datosDelObjeto', 'routeName'))->render(),

            ];
        });
        return response()->json($productos);
    }

    public function cambiarEstatus(Request $request)
    {
        $idProducto = $request->input('idRegistroParaEditar');
        $producto = Producto::findOrFail($idProducto);
        $nuevoEstatus = $producto->estatus === 'activo' ? 'inactivo' : 'activo';

        $producto->estatus = $nuevoEstatus;
        $producto->save();
        $estatusMensaje = $producto->estatus === 'activo' ? 'Habilitado' : 'Inhabilitada';

        return response()->json(['mensaje' => 'Estatus del Producto actualizado exitosamente.', 'nuevoEstatus' => $estatusMensaje]);
    }

    public function upload(Request $request)
    {
        // Validar la imagen y el ID del producto
        $request->validate([
            'file' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
            'producto_id' => 'required|integer|exists:productos,id',
        ]);

        // Subir la imagen a Imgur
        if ($request->hasFile('file')) {
            $image = $request->file('file');
            $client = new Client();
            $response = $client->post('https://api.imgur.com/3/upload', [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ],
                'multipart' => [
                    [
                        'name' => 'image',
                        'contents' => fopen($image->getPathname(), 'r'),
                        'filename' => $image->getClientOriginalName(),
                        'Mime-Type' => $image->getMimeType(),
                    ]
                ]
            ]);

            $responseBody = json_decode($response->getBody(), true);

            if (isset($responseBody['data']['link'])) {
                // Calcular el orden de la nueva imagen
                $maxOrder = ImagenProducto::where('producto_id', $request->producto_id)->max('order');
                $newOrder = $maxOrder + 1;

                // Guardar la URL de la imagen en la base de datos
                $imagenProducto = new ImagenProducto();
                $imagenProducto->producto_id = $request->producto_id;
                $imagenProducto->url_imagen = $responseBody['data']['link'];
                $imagenProducto->deletehash = $responseBody['data']['deletehash'];
                $imagenProducto->order = $newOrder;
                $imagenProducto->save();

                return response()->json(['id' => $imagenProducto->id, 'link' => $responseBody['data']['link']], 200);
            }

            return response()->json(['error' => 'No se pudo subir la imagen a Imgur'], 400);
        }

        return response()->json(['error' => 'No se pudo subir la imagen'], 400);
    }

    public function deleteImage(Request $request)
    {
        // Validar la solicitud
        $request->validate([
            'id' => 'required|integer|exists:imagens_productos,id',
        ]);

        // Buscar y eliminar la imagen
        $imagenProducto = ImagenProducto::find($request->id);
        if ($imagenProducto) {
            // Eliminar la imagen de Imgur
            $client = new Client();
            $response = $client->delete('https://api.imgur.com/3/image/' . $imagenProducto->deletehash, [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ]
            ]);

            if ($response->getStatusCode() == 200) {
                // Eliminar la imagen de la base de datos
                $imagenProducto->delete();

                return response()->json(['success' => 'Imagen eliminada con éxito'], 200);
            }

            return response()->json(['error' => 'No se pudo eliminar la imagen de Imgur'], 400);
        }

        return response()->json(['error' => 'No se pudo eliminar la imagen'], 400);
    }
}
