<?php

namespace App\Http\Controllers;

use App\Models\Proveedor;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use GuzzleHttp\Client;
use App\Http\Requests\StoreProveedorRequest;
use App\Http\Requests\UpdateProveedorRequest;

class ProveedorController extends Controller
{
    public function index()
    {
        return view('proveedor.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */


    public function store(StoreProveedorRequest $request)
    {
        // Validación
        $validator = Validator::make(
            $request->all(),
            [
                'nombres' => 'required|string|max:50',
                'apellidos' => 'required|string|max:50',
                'correo' => 'required|email|unique:users,email',
                'password' => 'required|string|min:6',
                'cedula' => 'required|numeric|unique:proveedores,cedula',
                'direccion' => 'required',
                'foto' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048'
            ],
            [
                'correo.required' => 'El Correo es obligatorio',
                'correo.unique' => 'El Correo ya está registrado',
                'correo.email' => 'No tiene un formato válido',
                'nombres.required' => 'Campo Nombres es Requerido',
                'nombres.min' => 'Campo Nombres requiere 5 caracteres mínimo',
                'nombres.max' => 'Campo Nombres no puede exceder 50 caracteres',

                'apellidos.required' => 'Campo Apellidos es Requerido',
                'apellidos.min' => 'Campo Apellidos requiere 5 caracteres mínimo',
                'apellidos.max' => 'Campo Apellidos no puede exceder 50 caracteres',

                'telefono.required' => 'Campo Teléfono es Requerido',
                'telefono.numeric' => 'El campo Teléfono debe ser numérico',
                'telefono.digits' => 'Campo Teléfono requiere 11 caracteres',

                'direccion.required' => 'Campo Dirección es Requerido',
                'direccion.min' => 'Campo Dirección requiere 5 caracteres mínimo',
                'direccion.max' => 'Campo Dirección no puede exceder los 200 caracteres',

                'cedula.required' => 'Campo Cédula es Requerido',
                'cedula.unique' => 'La cédula debe ser única',

                'foto.image' => 'El archivo debe ser una imagen',
                'foto.mimes' => 'La imagen debe ser un archivo de tipo: jpeg, png, jpg, gif',
                'foto.max' => 'La imagen no puede superar los 2 MB'
            ]
        );

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        // Subida de imagen a Imgur
        $foto = null;
        if ($request->file('foto')) {
            $imagen_name = $request->file('foto')->getClientOriginalName();
            $imagen_path = $request->file('foto')->getPathname();
            $imagen_mime = $request->file('foto')->getMimeType();
            $client = new Client();

            $response = $client->post('https://api.imgur.com/3/upload', [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ],
                'multipart' => [
                    [
                        'name' => 'image',
                        'filename' => $imagen_name,
                        'Mime-Type' => $imagen_mime,
                        'contents' => fopen($imagen_path, 'r'),
                    ]
                ]
            ]);

            $foto = json_decode($response->getBody()->getContents())->data->link;
        }

        // Crear el usuario
        $user = User::create([
            'name' => $request->nombres,
            'email' => $request->correo,
            'password' => Hash::make($request->password),
        ]);

        // Crear el proveedor asociado al usuario
        $proveedor = new proveedor([
            'nombres' => $request->nombres,
            'apellidos' => $request->apellidos,
            'cedula' => $request->cedula,
            'telefono' => $request->telefono,
            'direccion' => $request->direccion,
            'estatus' => 1,
            'foto' => $foto
        ]);

        $proveedor->user()->associate($user);
        $proveedor->save();

        return response()->json(['mensaje' => 'proveedor creado exitosamente', 'proveedor' => $proveedor]);
    }



    /**
     * Display the specified resource.
     */
    public function show($idProveedor)
    {
        // Usamos with('user') para cargar la relación user
        $proveedor = Proveedor::with('user')->findOrFail($idProveedor);
        return view('proveedor.perfil', compact('proveedor'));
    }



    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request)
    {
        $idproveedor = $request->input('idRegistroParaEditar');
        $proveedor = proveedor::findOrFail($idproveedor);
        return response()->json($proveedor);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update($request)
    {


        $idproveedor = $request->input('idproveedorEdicion');
        $validator = Validator::make(
            $request->all(),
            [
                'nombresEdit' => 'required|string|min:5|max:50',
                'apellidosEdit' => 'required|string|max:50',
                'direccionEdit' => 'required',
                'fotoEdit' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
                'telefonoEdit' => 'numeric|digits:11',
                'cedulaEdit' => ['required', 'numeric', Rule::unique('proveedor', 'cedula')->ignore($idproveedor),],
            ],
            [

                'nombresEdit.required' => 'Campo Nombres es Requerido',
                'nombresEdit.min' => 'Campo Nombres requiere 5 caracteres mínimo',
                'nombresEdit.max' => 'Campo Nombres no puede exceder 50 caracteres',

                'apellidosEdit.required' => 'Campo Apellidos es Requerido',
                'apellidosEdit.min' => 'Campo Apellidos requiere 5 caracteres mínimo',
                'apellidosEdit.max' => 'Campo Apellidos no puede exceder 50 caracteres',

                'telefonoEdit.required' => 'Campo Teléfono es Requerido',
                'telefonoEdit.numeric' => 'El campo Teléfono debe ser numérico',
                'telefonoEdit.digits' => 'Campo Teléfono requiere 11 caracteres',

                'direccionEdit.required' => 'Campo Dirección es Requerido',
                'direccionEdit.min' => 'Campo Dirección requiere 5 caracteres mínimo',
                'direccionEdit.max' => 'Campo Dirección no puede exceder los 200 caracteres',

                'cedulaEdit.required' => 'Campo Cedula es Requerido',
                'cedulaEdit.unique' => 'La cedula debe ser único'
            ]
        );

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        $foto = null;
        if ($request->file('fotoEdit')) {
            $imagen_name = $request->file('fotoEdit')->getClientOriginalName();
            $imagen_path = $request->file('fotoEdit')->getPathname();
            $imagen_mime = $request->file('fotoEdit')->getMimeType();
            $client = new Client();

            $response = $client->post('https://api.imgur.com/3/upload', [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ],
                'multipart' => [
                    [
                        'name' => 'image',
                        'filename' => $imagen_name,
                        'Mime-Type' => $imagen_mime,
                        'contents' => fopen($imagen_path, 'r'),
                    ]
                ]
            ]);

            $foto = json_decode($response->getBody()->getContents())->data->link;
        }

        // Encontrar el proveedor y actualizar los datos
        $proveedor = Proveedor::findOrFail($idproveedor);
        $proveedor->nombres = $request->input('nombresEdit');
        $proveedor->apellidos = $request->input('apellidosEdit');
        $proveedor->telefono = $request->input('telefonoEdit');
        $proveedor->direccion = $request->input('direccionEdit');
        $proveedor->cedula = $request->input('cedulaEdit');
        $proveedor->foto = $foto;
        $proveedor->save();

        return response()->json(['mensaje' => 'proveedor actualizado exitosamente.']);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Proveedor $proveedor)
    {
        //
    }

   
    public function obtenerProveedores()
    {
        $routeName = 'proveedor'; // Puedes modificar esto según el módulo
        $proveedor = proveedor::all()->map(function ($datosDelObjeto) use ($routeName) {
            return [
                'id'                => $datosDelObjeto->id,
                'nombres'           => $datosDelObjeto->nombres,
                'apellidos'         => $datosDelObjeto->apellidos,
                'telefono'          => $datosDelObjeto->telefono,
                'direccion'         => $datosDelObjeto->direccion,
                'cedula'            => $datosDelObjeto->cedula,
                'estatus'           => $datosDelObjeto->estatus,
                'correo'            => $datosDelObjeto->user->email,
                'foto'              => $datosDelObjeto->foto,
                'acciones'          => view('components.accionesFormulario', compact('datosDelObjeto', 'routeName'))->render(),

            ];
        });
        return response()->json($proveedor);
    }



    public function cambiarEstatus(Request $request)
    {
        $idproveedor = $request->input('idRegistroParaEditar');
        $proveedor = Proveedor::findOrFail($idproveedor);
        $nuevoEstatus = $proveedor->estatus === 'activo' ? 'inactivo' : 'activo';

        $proveedor->estatus = $nuevoEstatus;
        $proveedor->save();
        $estatusMensaje = $proveedor->estatus === 'activo' ? 'Habilitado' : 'Inhabilitada';

        return response()->json(['mensaje' => 'Estatus del proveedor actualizado exitosamente.', 'nuevoEstatus' => $estatusMensaje]);
    }
}
