<?php

namespace App\Http\Controllers;

use App\Models\Vendedor;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use GuzzleHttp\Client;


class VendedorController extends Controller
{
    public function index()
    {
        return view('vendedor.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validación
        $validator = Validator::make(
            $request->all(),
            [
                'nombres' => 'required|string|max:50',
                'apellidos' => 'required|string|max:50',
                'correo' => 'required|email|unique:users,email',
                'password' => 'required|string|min:6',
                'cedula' => 'required|numeric|unique:vendedores,cedula',
                'direccion' => 'required',
                'foto' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048'
            ],
            [
                'correo.required' => 'El Correo es obligatorio',
                'correo.unique' => 'El Correo ya está registrado',
                'correo.email' => 'No tiene un formato válido',
                'nombres.required' => 'Campo Nombres es Requerido',
                'nombres.min' => 'Campo Nombres requiere 5 caracteres mínimo',
                'nombres.max' => 'Campo Nombres no puede exceder 50 caracteres',

                'apellidos.required' => 'Campo Apellidos es Requerido',
                'apellidos.min' => 'Campo Apellidos requiere 5 caracteres mínimo',
                'apellidos.max' => 'Campo Apellidos no puede exceder 50 caracteres',

                'telefono.required' => 'Campo Teléfono es Requerido',
                'telefono.numeric' => 'El campo Teléfono debe ser numérico',
                'telefono.digits' => 'Campo Teléfono requiere 11 caracteres',

                'direccion.required' => 'Campo Dirección es Requerido',
                'direccion.min' => 'Campo Dirección requiere 5 caracteres mínimo',
                'direccion.max' => 'Campo Dirección no puede exceder los 200 caracteres',

                'cedula.required' => 'Campo Cédula es Requerido',
                'cedula.unique' => 'La cédula debe ser única',

                'foto.image' => 'El archivo debe ser una imagen',
                'foto.mimes' => 'La imagen debe ser un archivo de tipo: jpeg, png, jpg, gif',
                'foto.max' => 'La imagen no puede superar los 2 MB'
            ]
        );

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        // Subida de imagen a Imgur
        $foto = null;
        if ($request->file('foto')) {
            $imagen_name = $request->file('foto')->getClientOriginalName();
            $imagen_path = $request->file('foto')->getPathname();
            $imagen_mime = $request->file('foto')->getMimeType();
            $client = new Client();

            $response = $client->post('https://api.imgur.com/3/upload', [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ],
                'multipart' => [
                    [
                        'name' => 'image',
                        'filename' => $imagen_name,
                        'Mime-Type' => $imagen_mime,
                        'contents' => fopen($imagen_path, 'r'),
                    ]
                ]
            ]);

            $foto = json_decode($response->getBody()->getContents())->data->link;
        }

        // Crear el usuario
        $user = User::create([
            'name' => $request->nombres,
            'email' => $request->correo,
            'password' => Hash::make($request->password),
        ]);

        // Crear el vendedor asociado al usuario
        $vendedor = new Vendedor([
            'nombres' => $request->nombres,
            'apellidos' => $request->apellidos,
            'cedula' => $request->cedula,
            'telefono' => $request->telefono,
            'direccion' => $request->direccion,
            'estatus' => 'activo',
            'foto' => $foto
        ]);

        $vendedor->user()->associate($user);
        $vendedor->save();

        return response()->json(['mensaje' => 'Vendedor creado exitosamente', 'vendedor' => $vendedor]);
    }

    /**
     * Display the specified resource.
     */
    public function show($idVendedor)
    {
        // Usamos with('user') para cargar la relación user
        $vendedor = Vendedor::with('user')->findOrFail($idVendedor);
        return view('vendedor.perfil', compact('vendedor'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request)
    {
        $idVendedor = $request->input('idRegistroParaEditar');
        $vendedor = Vendedor::findOrFail($idVendedor);
        return response()->json($vendedor);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request)
    {
        $idVendedor = $request->input('idVendedorEdicion');
        $validator = Validator::make(
            $request->all(),
            [
                'nombresEdit' => 'required|string|min:5|max:50',
                'apellidosEdit' => 'required|string|max:50',
                'direccionEdit' => 'required',
                'fotoEdit' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
                'telefonoEdit' => 'numeric|digits:11',
                'cedulaEdit' => ['required', 'numeric', Rule::unique('vendedores', 'cedula')->ignore($idVendedor),],
            ],
            [
                'nombresEdit.required' => 'Campo Nombres es Requerido',
                'nombresEdit.min' => 'Campo Nombres requiere 5 caracteres mínimo',
                'nombresEdit.max' => 'Campo Nombres no puede exceder 50 caracteres',

                'apellidosEdit.required' => 'Campo Apellidos es Requerido',
                'apellidosEdit.min' => 'Campo Apellidos requiere 5 caracteres mínimo',
                'apellidosEdit.max' => 'Campo Apellidos no puede exceder 50 caracteres',

                'telefonoEdit.required' => 'Campo Teléfono es Requerido',
                'telefonoEdit.numeric' => 'El campo Teléfono debe ser numérico',
                'telefonoEdit.digits' => 'Campo Teléfono requiere 11 caracteres',

                'direccionEdit.required' => 'Campo Dirección es Requerido',
                'direccionEdit.min' => 'Campo Dirección requiere 5 caracteres mínimo',
                'direccionEdit.max' => 'Campo Dirección no puede exceder los 200 caracteres',

                'cedulaEdit.required' => 'Campo Cedula es Requerido',
                'cedulaEdit.unique' => 'La cedula debe ser único'
            ]
        );

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        $foto = null;
        if ($request->file('fotoEdit')) {
            $imagen_name = $request->file('fotoEdit')->getClientOriginalName();
            $imagen_path = $request->file('fotoEdit')->getPathname();
            $imagen_mime = $request->file('fotoEdit')->getMimeType();
            $client = new Client();

            $response = $client->post('https://api.imgur.com/3/upload', [
                'headers' => [
                    'Authorization' => 'Bearer 9fdadc2736c44f74f966eaf03f05c2dcec9309f4'
                ],
                'multipart' => [
                    [
                        'name' => 'image',
                        'filename' => $imagen_name,
                        'Mime-Type' => $imagen_mime,
                        'contents' => fopen($imagen_path, 'r'),
                    ]
                ]
            ]);

            $foto = json_decode($response->getBody()->getContents())->data->link;
        }

        // Encontrar el vendedor y actualizar los datos
        $vendedor = Vendedor::findOrFail($idVendedor);
        $vendedor->nombres = $request->input('nombresEdit');
        $vendedor->apellidos = $request->input('apellidosEdit');
        $vendedor->telefono = $request->input('telefonoEdit');
        $vendedor->direccion = $request->input('direccionEdit');
        $vendedor->cedula = $request->input('cedulaEdit');
        $vendedor->foto = $foto;
        $vendedor->save();

        return response()->json(['mensaje' => 'Vendedor actualizado exitosamente.']);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Vendedor $vendedor)
    {
        $vendedor->delete();
        return response()->json(['mensaje' => 'Vendedor eliminado exitosamente.']);
    }

    public function obtenerVendedores()
    {
        $routeName = 'vendedor'; // Puedes modificar esto según el módulo
        $vendedores = Vendedor::all()->map(function ($datosDelObjeto) use ($routeName) {
            return [
                'id'                => $datosDelObjeto->id,
                'nombres'           => $datosDelObjeto->nombres,
                'apellidos'         => $datosDelObjeto->apellidos,
                'telefono'          => $datosDelObjeto->telefono,
                'direccion'         => $datosDelObjeto->direccion,
                'cedula'            => $datosDelObjeto->cedula,
                'estatus'           => $datosDelObjeto->estatus,
                'correo'            => $datosDelObjeto->user->email,
                'foto'              => $datosDelObjeto->foto,
                'acciones'          => view('components.accionesFormulario', compact('datosDelObjeto', 'routeName'))->render(),
            ];
        });
        return response()->json($vendedores);
    }

    public function cambiarEstatus(Request $request)
    {
        $idVendedor = $request->input('idRegistroParaEditar');
        $vendedor = Vendedor::findOrFail($idVendedor);
        $nuevoEstatus = $vendedor->estatus === 'activo' ? 'inactivo' : 'activo';

        $vendedor->estatus = $nuevoEstatus;
        $vendedor->save();
        $estatusMensaje = $vendedor->estatus === 'activo' ? 'Habilitado' : 'Inhabilitado';

        return response()->json(['mensaje' => 'Estatus del vendedor actualizado exitosamente.', 'nuevoEstatus' => $estatusMensaje]);
    }
}
