<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Producto extends Model
{
    use HasFactory;
    protected $table = 'productos';
    protected $fillable = [
        'nombre_producto',
        'descripcion',
        'cantidad',
        'precio_compra',
        'precio_venta',
        'precio_maximo_vendedor',
        'sku',
        'categoria_id',
        'almacen_id',
        'proveedor_id',
        'fecha_caducidad',
        'nivel_reorden',
        'estado',
        'descuento',
        'fecha_inicio_descuento',
        'fecha_fin_descuento',
        'creado_por',
        'afiliado_id',
        'actualizado_por',
        'id_subcategoria'
    ];

    public function categoria()
    {
        return $this->belongsTo(Categoria::class);
    }
 
    public function almacen()
    {
        return $this->belongsTo(Almacen::class);
    }

    public function proveedor()
    {
        return $this->belongsTo(Proveedor::class);
    }

    public function creadoPor()
    {
        return $this->belongsTo(User::class, 'creado_por');
    }

    public function actualizadoPor()
    {
        return $this->belongsTo(User::class, 'actualizado_por');
    }

    public function imagenes()
    {
        return $this->hasMany(ImagenProducto::class);
    }

    // Definir una relación para obtener la imagen con orden 1
    public function imagenPrincipal()
    {
        return $this->hasOne(ImagenProducto::class)->where('order', 1);
    }
    public function afiliados()
    {
        return $this->belongsToMany(Afiliado::class, 'afiliados_productos')->withPivot('cantidad', 'stock')->withTimestamps();
    }
    public function empresas()
    {
        return $this->belongsToMany(Empresa::class, 'empresa_productos')->withPivot('cantidad', 'stock')->withTimestamps();
    }
}
