<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateProductosTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */


     public function up()
     {
         Schema::create('productos', function (Blueprint $table) {
             $table->id();
             $table->string('nombre_producto');
             $table->text('descripcion')->nullable();
             $table->integer('cantidad')->default(0); // Cantidad por defecto 0
             $table->decimal('precio_compra', 8, 2);
             $table->decimal('precio_venta', 8, 2);
             $table->decimal('precio_maximo_vendedor', 8, 2); // Precio de venta para vendedores
             $table->string('sku')->unique(); // Código de Producto
             $table->unsignedBigInteger('categoria_id');
             $table->unsignedBigInteger('almacen_id');

             $table->unsignedBigInteger('proveedor_id'); // Relacionar con la tabla proveedores
             $table->date('fecha_caducidad')->nullable(); // Fecha de Caducidad
             $table->integer('nivel_reorden')->default(0); // Nivel de Reorden
             $table->enum('estatus', ['activo', 'inactivo'])->default('activo');
             $table->decimal('descuento', 5, 2)->default(0.00); // Porcentaje de descuento

             $table->date('fecha_inicio_descuento')->nullable();
             $table->date('fecha_fin_descuento')->nullable();
             $table->unsignedBigInteger('creado_por')->nullable();
             $table->unsignedBigInteger('actualizado_por')->nullable();
             $table->timestamps(); // Crea los campos created_at y updated_at

             // Relación con la tabla categorias
             $table->foreign('categoria_id')->references('id')->on('categorias')->onDelete('cascade');

             // Relación con la tabla almacenes
             $table->foreign('almacen_id')->references('id')->on('almacenes')->onDelete('cascade');

             // Relación con la tabla proveedores
             $table->foreign('proveedor_id')->references('id')->on('proveedores')->onDelete('cascade');
            // Relación con la tabla categorias
            

            });
     }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('productos');
    }
}
