$(document).ready(function () {
    tablaDeCategorias();

    function tablaDeCategorias() {
        $.ajax({
            url: "/categoria/lista",
            type: "GET",
            success: function (data) {
                tabla_suc = $('#categorias-table').dataTable({
                    responsive: {
                        details: {
                            type: 'column',
                            target: 0
                        }
                    },
                    lengthChange: true,
                    autoWidth: true,
                    data: data,
                    language: {
                        lengthMenu: "Mostrar _MENU_ Registros por pagina",
                        zeroRecords: "No tenemos Coincidencias",
                        info: "Pagina Mostrada _PAGE_ of _PAGES_",
                        infoEmpty: "No records available",
                        infoFiltered: "(filtered from _MAX_ total records)",
                        search: "Buscar:",
                        loadingRecords: "Cargando...",
                        emptyTable: "No hay información",
                        paginate: {
                            first: "Primero",
                            last: "Ultimo",
                            next: "<i class='ri-arrow-right-s-line'></i>",
                            previous: "<i class='ri-arrow-left-s-line'></i>",
                        },
                        info: "Mostrando _PAGE_ de _PAGES_ del total de Paginas",
                        infoEmpty: "Mostrando 0 to 0 of 0 Entradas",
                        infoFiltered: "(Filtrado de MAX total entradas)",
                    },
                    destroy: true,
                    columns: [
                        {
                            className: 'dtr-control',
                            orderable: false,
                            data: null,
                            defaultContent: '',
                        },
                        {
                            data: "nombre",
                            className:
                                "text-dark text-x font-weight-bolder opacity-8 text-center",
                            render: function (data, type, row) {
                                return `<span class="categoria-nombre" data-id="${row.id}">${data}</span>`;
                            },
                        },
                        {
                            data: "descripcion",
                            className:
                                "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                        {
                            data: "cantArticulos",
                            className:
                                "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                        {
                            data: "estatus",
                            name: "estatus",
                            className:
                                "text-dark text-x font-weight-bolder opacity-8 text-center",
                            render: function (data) {
                                if (data === "activo") {
                                    return '<span class="badge rounded-pill bg-success">Activo</span>';
                                } else {
                                    return '<span class="badge rounded-pill bg-danger">Inactivo</span>';
                                }
                            },
                        },
                        {
                            data: "acciones",
                            className:
                                "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                    ],
                    lengthMenu: [
                        [5, 10, 25, -1],
                        [5, 10, 25, "All"],
                    ],
                });

                // Manejar el clic en el nombre de la categoría para mostrar las subcategorías en un modal
                $("#categorias-table tbody").on(
                    "click",
                    ".categoria-nombre",
                    function () {
                        var categoriaId = $(this).data("id");

                        $.ajax({
                            url: `/categoria/${categoriaId}/subcategorias`,
                            type: "GET",
                            success: function (data) {
                                var tabla_subCategoria = $(
                                    "#subcategorias-table"
                                ).DataTable({
                                    responsive: true,
                                    lengthChange: true,
                                    autoWidth: true,
                                    data: data,
                                    language: {
                                        lengthMenu:
                                            "Mostrar _MENU_ Registros por pagina",
                                        zeroRecords: "No tenemos Coincidencias",
                                        info: "Pagina Mostrada _PAGE_ of _PAGES_",
                                        infoEmpty: "No records available",
                                        infoFiltered:
                                            "(filtered from _MAX_ total records)",
                                        search: "Buscar:",
                                        loadingRecords: "Cargando...",
                                        emptyTable: "No hay información",
                                        paginate: {
                                            first: "Primero",
                                            last: "Ultimo",
                                            next: "<i class='ri-arrow-right-s-line'></i>",
                                            previous:
                                                "<i class='ri-arrow-left-s-line'></i>",
                                        },
                                        info: "Mostrando _PAGE_ de _PAGES_ del total de Paginas",
                                        infoEmpty:
                                            "Mostrando 0 to 0 of 0 Entradas",
                                        infoFiltered:
                                            "(Filtrado de MAX total entradas)",
                                    },
                                    destroy: true,
                                    columns: [
                                        {
                                            data: "nombre",
                                            className:
                                                "text-dark text-x font-weight-bolder opacity-8 text-center",
                                        },
                                        {
                                            data: "descripcion",
                                            className:
                                                "text-dark text-x font-weight-bolder opacity-8 text-center",
                                        },

                                        {
                                            data: "acciones",
                                            className:
                                                "text-dark text-x font-weight-bolder opacity-8 text-center",
                                        },
                                    ],
                                    lengthMenu: [
                                        [5, 10, 25, -1],
                                        [5, 10, 25, "All"],
                                    ],
                                });

                                $("#subcategoriasModal").modal("show");
                            },
                        });
                    }
                );
            },
        });
    }

    $("#form-categoria").on("submit", function (e) {
        e.preventDefault(); // Prevenir el comportamiento por defecto del formulario

        // Eliminar mensajes de error y clases de error existentes
        $(".is-invalid").removeClass("is-invalid");
        $(".invalid-feedback").remove();

        $.ajax({
            url: "/categoria/store",
            type: "POST",
            data: new FormData(this),
            contentType: false,
            processData: false,
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            success: function (response) {
                // Manejar la respuesta de éxito
                Swal.fire({
                    icon: "success",
                    title: "categoria Registrado con Exito",
                    showConfirmButton: false,
                    customClass: {
                        confirmButton:
                            "btn btn-primary waves-effect waves-light",
                    },
                    buttonsStyling: false,
                });
                // Limpiar el formulario y cerrar el offcanvas
                $("#form-categoria")[0].reset();
                $("#offcanvasRegistro").offcanvas("hide");
                tablaDeCategorias();
            },
            error: function (xhr, status, error) {
                // Manejar errores
                if (xhr.status === 422) {
                    // Errores de validación
                    var errors = xhr.responseJSON.errors;
                    var errorMessages = "";

                    $.each(errors, function (key, value) {
                        errorMessages += value[0] + "\n"; // Concatenar mensajes de error
                        // Mostrar mensajes de error en los campos del formulario
                        $("#" + key).addClass("is-invalid");
                        $("#" + key).after(
                            '<div class="invalid-feedback">' +
                                value[0] +
                                "</div>"
                        );
                    });
                } else {
                    // Otro tipo de errores
                    alert("Error al registrar el categoria.");
                }
            },
        });
    });

    $(document).on("submit", "#formEdit", function (a) {
        a.preventDefault();

        // Eliminar mensajes de error y clases de error existentes
        $(".is-invalid").removeClass("is-invalid");
        $(".invalid-feedback").remove();

        $.ajax({
            url: "/categoria/editar",
            method: "POST",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            data: new FormData(this),
            contentType: false,
            processData: false,
            success: function (response) {
                $("#offcanvasEditar").offcanvas("show");
                $("#idcategoriaEdicion").val(response.id);
                $("#nombreEditar").val(response.nombre_categoria);
                $("#sucursalIdEditar").val(response.sucursal_id);
                $("#descripcionEditar").val(response.descripcion);
                $("#direccionEditar").val(response.ubicacion);

                $("#formUpdate").submit(function (b) {
                    b.preventDefault();
                    b.stopImmediatePropagation();
                    var form = $("#formUpdate")[0];
                    var data = new FormData(form);
                    $.ajax({
                        url: "/categoria/update",
                        type: "POST",
                        data: data,
                        cache: false,
                        contentType: false,
                        processData: false,
                        headers: {
                            "X-HTTP-Method-Override": "PUT",
                            "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr(
                                "content"
                            ),
                        },
                        success: function (response) {
                            $(".is-invalid").removeClass("is-invalid");
                            $(".invalid-feedback").remove();
                            tablaDeCategorias();
                            $("#offcanvasEditar").offcanvas("hide");
                            Swal.fire({
                                icon: "success",
                                title: "Actualización Exitosa",
                                showConfirmButton: false,
                                customClass: {
                                    confirmButton:
                                        "btn btn-primary waves-effect waves-light",
                                },
                                buttonsStyling: false,
                            });
                        },
                        error: function (xhr, status, error) {
                            $(".is-invalid").removeClass("is-invalid");
                            $(".invalid-feedback").remove();
                            console.error(
                                "Error al actualizar el categoria:",
                                error
                            );

                            if (xhr.responseJSON && xhr.responseJSON.errors) {
                                var errors = xhr.responseJSON.errors;
                                for (var field in errors) {
                                    var inputField = $("[name=" + field + "]");
                                    inputField.addClass("is-invalid");
                                    if (
                                        inputField.next(".invalid-feedback")
                                            .length
                                    ) {
                                        inputField
                                            .next(".invalid-feedback")
                                            .text(errors[field][0]);
                                    } else {
                                        inputField.after(
                                            '<div class="invalid-feedback">' +
                                                errors[field][0] +
                                                "</div>"
                                        );
                                    }
                                }
                            }
                        },
                    });
                });
            },
        });
    });

    $(document).on("submit", "#formCambiarEstatus", function (a) {
        a.preventDefault();
        $.ajax({
            url: "/categoria/cambiarEstatus",
            method: "POST",
            data: new FormData(this),
            contentType: false,
            processData: false,
            headers: {
                "X-HTTP-Method-Override": "PATCH",
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            success: function (response) {
                console.log(response.nuevoEstatus);
                tablaDeCategorias();
                Swal.fire({
                    icon: "success",
                    title: response.mensaje,
                    text: "categoria " + response.nuevoEstatus + " con exito",
                    showConfirmButton: false,
                    customClass: {
                        confirmButton:
                            "btn btn-primary waves-effect waves-light",
                    },
                    buttonsStyling: false,
                });
            },
        });
    });
    cargarSucursalesHabilitadas();

    function cargarSucursalesHabilitadas() {
        $.ajax({
            url: "/sucursales/habilitadas",
            type: "GET",
            success: function (data) {
                var select = $("#sucursal_id");
                select.empty();

                data.forEach(function (sucursal) {
                    select.append(
                        '<option value="' +
                            sucursal.id +
                            '" selected>' +
                            sucursal.nombre_sucursal +
                            " (" +
                            sucursal.categoriaes_count +
                            " categoriaes)</option>"
                    );
                });
            },
            error: function (xhr, status, error) {
                console.error(
                    "Error al cargar las sucursales habilitadas:",
                    error
                );
            },
        });
    }
    cargarSucursalesHabilitadasParaEditarcategoria();
    function cargarSucursalesHabilitadasParaEditarcategoria() {
        $.ajax({
            url: "/sucursales/habilitadas",
            type: "GET",
            success: function (data) {
                var select = $("#sucursalIdEditar");
                select.empty();

                data.forEach(function (sucursal) {
                    select.append(
                        '<option value="' +
                            sucursal.id +
                            '" selected>' +
                            sucursal.nombre_sucursal +
                            " (" +
                            sucursal.categoriaes_count +
                            " categoriaes)</option>"
                    );
                });
            },
            error: function (xhr, status, error) {
                console.error(
                    "Error al cargar las sucursales habilitadas:",
                    error
                );
            },
        });
    }

//Funcion Registrar Sub-Categoria
    $(document).on("submit", "#formRegSubCategoria", function (a) {
        a.preventDefault();

        // Eliminar mensajes de error y clases de error existentes
        $(".is-invalid").removeClass("is-invalid");
        $(".invalid-feedback").remove();

        $.ajax({
            url: "/categoria/editar",
            method: "POST",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            data: new FormData(this),
            contentType: false,
            processData: false,
            success: function (response) {
                $("#offcanvasRegistroSubCategoria").offcanvas("show");

                $("#idCategoriaRegistroSubCategoria").val(response.id);


                $("#form-subcategoria").submit(function (b) {
                    b.preventDefault();
                    b.stopImmediatePropagation();
                    var form = $("#form-subcategoria")[0];
                    var data = new FormData(form);
                    $.ajax({
                        url: "/categoria/store-subcategoria",
                        type: "POST",
                        data: data,
                        cache: false,
                        contentType: false,
                        processData: false,
                        headers: {
                            "X-HTTP-Method-Override": "POST",
                            "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr(
                                "content"
                            ),
                        },
                        success: function (response) {
                            $(".is-invalid").removeClass("is-invalid");
                            $(".invalid-feedback").remove();
                            tablaDeCategorias();
                            $("#offcanvasRegistroSubCategoria").offcanvas("hide");
                            Swal.fire({
                                icon: "success",
                                title: "Registro de Sub-Categoria Exitosa",
                                showConfirmButton: false,
                                customClass: {
                                    confirmButton:
                                        "btn btn-primary waves-effect waves-light",
                                },
                                buttonsStyling: false,
                            });
                        },
                        error: function (xhr, status, error) {
                            $(".is-invalid").removeClass("is-invalid");
                            $(".invalid-feedback").remove();
                            console.error(
                                "Error al Registrar la sub-categoria:",
                                error
                            );

                            if (xhr.responseJSON && xhr.responseJSON.errors) {
                                var errors = xhr.responseJSON.errors;
                                for (var field in errors) {
                                    var inputField = $("[name=" + field + "]");
                                    inputField.addClass("is-invalid");
                                    if (
                                        inputField.next(".invalid-feedback")
                                            .length
                                    ) {
                                        inputField
                                            .next(".invalid-feedback")
                                            .text(errors[field][0]);
                                    } else {
                                        inputField.after(
                                            '<div class="invalid-feedback">' +
                                                errors[field][0] +
                                                "</div>"
                                        );
                                    }
                                }
                            }
                        },
                    });
                });
            },
        });
    });
});
