$(document).ready(function () {
    tablaDeProductos();

    function tablaDeProductos() {
        $.ajax({
            url: "/producto/lista",
            type: "GET",
            success: function (data) {
                tabla_suc = $("#producto-table").DataTable({
                    responsive: true,
                    lengthChange: true,
                    autoWidth: true,
                    data: data,
                    language: {
                        lengthMenu: "Mostrar _MENU_ Registros por pagina",
                        zeroRecords: "No tenemos Coincidencias",
                        info: "Pagina Mostrada _PAGE_ of _PAGES_",
                        infoEmpty: "No records available",
                        infoFiltered: "(filtered from _MAX_ total records)",
                        search: "Buscar:",
                        loadingRecords: "Cargando...",
                        emptyTable: "No hay información",
                        paginate: {
                            first: "Primero",
                            last: "Ultimo",
                            next: "<i class='ri-arrow-right-s-line'></i>",
                            previous: "<i class='ri-arrow-left-s-line'></i>",
                        },
                        info: "Mostrando _PAGE_ de _PAGES_ del total de Paginas",
                        infoEmpty: "Mostrando 0 to 0 of 0 Entradas",
                        infoFiltered: "(Filtrado de MAX total entradas)",
                    },
                    destroy: true,
                    columns: [
                        {

                            orderable: false,
                            data: null,
                            defaultContent: '',
                            className: 'text-dark text-x font-weight-bolder opacity-8 text-center',

                        },
                        {
                            data: null,
                            className: "text-dark text-x font-weight-bolder opacity-8 text-center",
                            render: function (data) {
                                let imgHtml = data.imagen ? `<img src="${data.imagen}" alt="Imagen del producto" class="rounded-2" style="width: 70px; height: 70px; object-fit: cover; margin-right: 10px;">` : "Sin imagen";
                                return `<div class="d-flex align-items-center">${imgHtml}<span>${data.nombre}</span></div>`;
                            },
                        },
                        {
                            data: "descripcion",
                            className: "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                        {
                            data: "cantArticulos",
                            className: "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                        {
                            data: "precio_compra",
                            className: "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                        {
                            data: "categoria",
                            className: "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                        {
                            data: "proveedor",
                            className: "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                        {
                            data: "estatus",
                            name: "estatus",
                            className: "text-dark text-x font-weight-bolder opacity-8 text-center",
                            render: function (data) {
                                if (data === "activo") {
                                    return '<span class="badge rounded-pill bg-success">Activo</span>';
                                } else {
                                    return '<span class="badge rounded-pill bg-danger">Inactivo</span>';
                                }
                            },
                        },
                        {
                            data: "acciones",
                            className: "text-dark text-x font-weight-bolder opacity-8 text-center",
                        },
                    ],
                    lengthMenu: [
                        [5, 10, 25, -1],
                        [5, 10, 25, "All"],
                    ],
                });


            },
        });
    }

    // Función para formatear los detalles de la fila
    function format(d) {
        // Aquí puedes añadir cualquier contenido adicional que quieras mostrar al expandir la fila
        return `<div>Detalles adicionales para el producto: ${d.nombre}</div>`;
    }

    $("#form-producto").on("submit", function (e) {
        e.preventDefault(); // Prevenir el comportamiento por defecto del formulario

        // Eliminar mensajes de error y clases de error existentes
        $(".is-invalid").removeClass("is-invalid");
        $(".invalid-feedback").remove();

        $.ajax({
            url: "/producto/store",
            type: "POST",
            data: new FormData(this),
            contentType: false,
            processData: false,
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            success: function (response) {
                // Manejar la respuesta de éxito
                tablaDeProductos()
                Swal.fire({
                    icon: "success",
                    title: "Producto Registrado con Exito",
                    showConfirmButton: false,
                    customClass: {
                        confirmButton:
                            "btn btn-primary waves-effect waves-light",
                    },
                    buttonsStyling: false,
                });
                // Limpiar el formulario y cerrar el offcanvas
                $("#form-producto")[0].reset();
                $("#offcanvasRegistro").offcanvas("hide");
                
                $(document).trigger('productoRegistrado', response);
            },
            error: function (xhr, status, error) {
                // Manejar errores
                if (xhr.status === 422) {
                    // Errores de validación
                    var errors = xhr.responseJSON.errors;
                    var errorMessages = "";

                    $.each(errors, function (key, value) {
                        errorMessages += value[0] + "\n"; // Concatenar mensajes de error
                        // Mostrar mensajes de error en los campos del formulario
                        $("#" + key).addClass("is-invalid");
                        $("#" + key).after(
                            '<div class="invalid-feedback">' +
                                value[0] +
                                "</div>"
                        );
                    });
                } else {
                    // Otro tipo de errores
                    alert("Error al registrar el Afiliado.");
                }
            },
        });
    });

    $(document).on("submit", "#formEdit", function (a) {
        a.preventDefault();

        // Eliminar mensajes de error y clases de error existentes
        $(".is-invalid").removeClass("is-invalid");
        $(".invalid-feedback").remove();

        $.ajax({
            url: "/producto/editar",
            method: "POST",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            data: new FormData(this),
            contentType: false,
            processData: false,
            success: function (response) {
                $("#offcanvasEditar").offcanvas("show");
                $("#idProductoEdicion").val(response.id);
                $("#nombre_producto_edit").val(response.nombre_producto);
                $("#descripcionEdit").val(response.descripcion);
                $("#skuEdit").val(response.sku);
                $("#precio_compraEdit").val(response.precio_compra);
                $("#precio_ventaEdit").val(response.precio_venta);
                $("#almacen_idEdit").val(response.almacen_id);
                $("#categoria_idEdit").val(response.categoria_id);
                $("#proveedor_idEdit").val(response.proveedor_id);
                $("#afiliado_idEdit").val(response.afiliado_id);
                $("#fecha_caducidadEdit").val(response.fecha_caducidad);

                $("#precio_maximo_vendedorEdit").val(response.precio_maximo_vendedor);
                $("#formUpdate").submit(function (b) {
                    b.preventDefault();
                    b.stopImmediatePropagation();
                    var form = $("#formUpdate")[0];
                    var data = new FormData(form);
                    $.ajax({
                        url: "/producto/update",
                        type: "POST",
                        data: data,
                        cache: false,
                        contentType: false,
                        processData: false,
                        headers: {
                            "X-HTTP-Method-Override": "PUT",
                            "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr(
                                "content"
                            ),
                        },
                        success: function (response) {
                            $(".is-invalid").removeClass("is-invalid");
                            $(".invalid-feedback").remove();
                            tablaDeProductos();
                            $("#offcanvasEditar").offcanvas("hide");
                            Swal.fire({
                                icon: "success",
                                title: "Actualización Exitosa",
                                showConfirmButton: false,
                                customClass: {
                                    confirmButton:
                                        "btn btn-primary waves-effect waves-light",
                                },
                                buttonsStyling: false,
                            });
                        },
                        error: function (xhr, status, error) {
                            $(".is-invalid").removeClass("is-invalid");
                            $(".invalid-feedback").remove();
                            console.error(
                                "Error al actualizar el Afiliado:",
                                error
                            );

                            if (xhr.responseJSON && xhr.responseJSON.errors) {
                                var errors = xhr.responseJSON.errors;
                                for (var field in errors) {
                                    var inputField = $("[name=" + field + "]");
                                    inputField.addClass("is-invalid");
                                    if (inputField.next(".invalid-feedback").length) {
                                        inputField.next(".invalid-feedback").text(errors[field][0]);
                                    } else {
                                        inputField.after(
                                            '<div class="invalid-feedback">' + errors[field][0] + '</div>'
                                        );
                                    }
                                }
                            }
                        },
                    });
                });
            },
        });
    });


    $(document).on("submit", "#formCambiarEstatus", function (a) {
        a.preventDefault();
        $.ajax({
            url: "/producto/cambiarEstatus",
            method: "POST",
            data: new FormData(this),
            contentType: false,
            processData: false,
            headers: {
                "X-HTTP-Method-Override": "PATCH",
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            success: function (response) {
                console.log(response.nuevoEstatus);
                tablaDeProductos();
                Swal.fire({
                    icon: "success",
                    title: response.mensaje,
                    text: "Producto " + response.nuevoEstatus + " con exito",
                    showConfirmButton: false,
                    customClass: {
                        confirmButton:
                            "btn btn-primary waves-effect waves-light",
                    },
                    buttonsStyling: false,
                });
            },
        });
    });


    $(document).on("submit", "#formSubirImagen", function (a) {
        a.preventDefault();

        // Eliminar mensajes de error y clases de error existentes
        $(".is-invalid").removeClass("is-invalid");
        $(".invalid-feedback").remove();

        $.ajax({
            url: "/producto/editar",
            method: "POST",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            data: new FormData(this),
            contentType: false,
            processData: false,
            success: function (response) {
                $("#modalCargarImg").modal("show");
                $("#producto_id_Img").val(response.id);
                $("#nombreProductoImg").text(response.nombre_producto);

            },
        });
    });

    $('#categoria_id').on('change', function() {
        var categoriaId = $(this).val();
        if (categoriaId) {
            $.ajax({
                url: `/categoria/${categoriaId}/subcategorias`,
                type: "GET",
                success: function (subcategorias) {
                    var subcategoriasOptions = '<option value="">Seleccione una subcategoría</option>';
                    if (subcategorias.length > 0) {
                        subcategorias.forEach(function (subcategoria) {
                            subcategoriasOptions += `<option value="${subcategoria.id}">${subcategoria.nombre}</option>`;
                        });
                    } else {
                        subcategoriasOptions = '<option value="">No posee subcategorías</option>';
                    }
                    $('#subcategoria_id').html(subcategoriasOptions);
                    $('#subcategoria-container').show(); // Mostrar el contenedor del select de subcategorías
                }
            });
        } else {
            $('#subcategoria_id').html('<option value="">Seleccione una subcategoría</option>');
            $('#subcategoria-container').hide(); // Ocultar el contenedor del select de subcategorías
        }
    });
});
