@extends('layouts.plantilla')
@section('title', 'Dashboard')
<link rel="stylesheet" href="{{ asset('vendor/libs/sweetalert2/sweetalert2.css') }}" />
@section('contenidoPrincipal')
    @if (isset($empresa) ? ($imagenLogo = $empresa->logo) : ($imagenLogo = asset('img/avatars/1.png')))
    @endif
    <div class="col-xl">
        <div class="card mb-6">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">Perfil de la Empresa</h5>
                <small class="text-body float-end">Registra tu empresa.</small>
            </div>
            <div class="card-body">
                <div id="form-errors" class="alert alert-danger" style="display: none;"></div>

                @if (session('actualizacion'))
                    <div id="form-errors" class="alert alert-success">
                        {{ session('actualizacion') }}
                    </div>
                @endif

                @if (isset($empresa))
                    <form id="empresa-form" class="needs-validation" enctype="multipart/form-data" novalidate>
                        @method('PUT')
                    @else
                        <form id="empresa-form" class="needs-validation" enctype="multipart/form-data" novalidate>
                @endif
                @csrf
                <div class="card-body">
                    <div class="d-flex align-items-start align-items-sm-center gap-6">
                        <img src="{{  $imagenLogo }}" alt="user-avatar" class="d-block w-px-100 h-px-100 rounded-4"
                            id="uploadedAvatar" />
                        <div class="button-wrapper">
                            <label for="logo" class="btn btn-primary me-3 mb-4" tabindex="0">
                                <span class="d-none d-sm-block">Subir Imagen | Logo</span>
                                <i class="ri-upload-2-line d-block d-sm-none"></i>
                                <input type="file" id="logo" name="logo" class="account-file-input" hidden
                                    accept="image/png, image/jpeg" />
                            </label>
                            <button type="button" class="btn btn-outline-danger account-image-reset mb-4">
                                <i class="ri-refresh-line d-block d-sm-none"></i>
                                <span class="d-none d-sm-block">Resetear</span>
                            </button>
                            <div>Sube tu imagen JPG o PNG. Tamaño máximo 2 Megabytes</div>
                        </div>
                    </div>
                </div>
                <div class="input-group input-group-merge mb-6">
                    <span id="basic-icon-default-company2" class="input-group-text"><i
                            class="ri-building-4-line"></i></span>
                    <div class="form-floating form-floating-outline">
                        <input type="text" class="form-control" name="nombre_empresa" id="nombre_empresa"
                            placeholder="Mi Tiendita Online" aria-label="Mi Tiendita Online"
                            aria-describedby="basic-icon-default-company2"
                            value="{{ $empresa->nombre_empresa ?? old('nombre_empresa') }}" required />
                        <label for="basic-icon-default-company2">Nombre de la Empresa</label>
                        <div class="invalid-feedback">El nombre de la empresa es obligatorio y debe tener entre 5 y 50
                            caracteres.</div>
                    </div>
                </div>
                <div class="input-group input-group-merge mb-6">
                    <span id="basic-icon-default-company2" class="input-group-text"><i class="ri-id-card-line"></i></span>
                    <div class="form-floating form-floating-outline">
                        <input type="text" id="rif" name="rif" class="form-control" placeholder="J-123456789."
                            aria-label="ACME Inc." aria-describedby="basic-icon-default-company2"
                            value="{{ $empresa->rif ?? old('rif') }}" required />
                        <label for="basic-icon-default-company">Rif</label>
                        <div class="invalid-feedback">El RIF es obligatorio.</div>
                    </div>
                </div>
                <div class="mb-6">
                    <div class="input-group input-group-merge">
                        <span class="input-group-text"><i class="ri-mail-line"></i></span>
                        <div class="form-floating form-floating-outline">
                            <input type="email" id="email" name="email" class="form-control"
                                value="{{ $empresa->email ?? old('email') }}" placeholder="john.doe" aria-label="john.doe"
                                aria-describedby="basic-icon-default-email2" required />
                            <label for="basic-icon-default-email">Email</label>
                            <div class="invalid-feedback">El correo electrónico es obligatorio y debe tener un formato
                                válido.</div>
                        </div>
                    </div>
                </div>
                <div class="input-group input-group-merge mb-6">
                    <span id="basic-icon-default-phone2" class="input-group-text"><i class="ri-phone-fill"></i></span>
                    <div class="form-floating form-floating-outline">
                        <input type="text" id="telefono" name="telefono" class="form-control phone-mask"
                            onkeypress="return validarCampo(event)" value="{{ $empresa->telefono ?? old('telefono') }}"
                            placeholder="0412 123 8941" aria-label="658 799 8941"
                            aria-describedby="basic-icon-default-phone2" minlength="11" maxlength="11" required />
                        <label for="basic-icon-default-phone">Número Teléfono</label>
                        <div class="invalid-feedback">El teléfono es obligatorio y debe tener 11 dígitos.</div>
                    </div>
                </div>
                <div class="input-group input-group-merge mb-6">
                    <span id="basic-icon-default-message2" class="input-group-text"><i
                            class="ri-road-map-line"></i></span>
                    <div class="form-floating form-floating-outline">
                        <textarea id="direccion" name="direccion" class="form-control" placeholder="Dirección de la empresa"
                            aria-label="Dirección de la empresa" aria-describedby="basic-icon-default-message2" style="height: 60px"
                            required>{{ $empresa->direccion ?? old('direccion') }}</textarea>
                        <label for="basic-icon-default-message">Dirección</label>
                        <div class="invalid-feedback">La dirección es obligatoria y debe tener entre 5 y 200 caracteres.
                        </div>
                    </div>
                </div>
                <button type="submit"
                    class="btn btn-primary">{{ isset($empresa) ? 'Actualizar Empresa' : 'Registrar Empresa' }}</button>
                </form>
            </div>
        </div>
    </div>
@endsection

@section('pluginsJs')
    <!-- Vendors JS -->
    <script src="{{ asset('vendor/libs/@form-validation/bootstrap5.js') }}"></script>
    <script src="{{ asset('vendor/libs/sweetalert2/sweetalert2.js') }}"></script>

    <!-- Main JS -->
    <script src="{{ asset('js/main.js') }}"></script>
    <!-- Page JS -->
    <script src="{{ asset('aplicacionJs/empresa.js') }}"></script>

    <!-- Script AJAX -->
    <script>
        (function() {
            'use strict'

            // Fetch all the forms we want to apply custom Bootstrap validation styles to
            var forms = document.querySelectorAll('.needs-validation')

            // Loop over them and prevent submission
            Array.prototype.slice.call(forms)
                .forEach(function(form) {
                    form.addEventListener('submit', function(event) {
                        if (!form.checkValidity()) {
                            event.preventDefault()
                            event.stopPropagation()
                        }

                        form.classList.add('was-validated')
                    }, false)
                })
        })()

        $(document).ready(function() {
            $('#empresa-form').on('submit', function(e) {
                e.preventDefault();

                if (!this.checkValidity()) {
                    e.stopPropagation();
                    return;
                }

                let formData = new FormData(this);
                let url =
                    '{{ isset($empresa) ? route('empresa.update', $empresa->id) : route('empresa.store') }}';
                let method =
                    '{{ isset($empresa) ? 'POST' : 'POST' }}'; // Always use POST for FormData with _method field
                let mensaje = '{{ isset($empresa) ? 'Actualizacion Exitosa' : 'Registro Exitoso' }}'
                $.ajax({
                    url: url,
                    method: method,
                    data: formData,
                    processData: false,
                    contentType: false,
                    success: function(response) {
                        Swal.fire({

                            icon: 'success',
                            title: mensaje,
                            showConfirmButton: false,
                            customClass: {
                                confirmButton: 'btn btn-primary waves-effect waves-light'
                            },
                            buttonsStyling: false
                        });
                    },
                    error: function(response) {
                        let errors = response.responseJSON.errors;
                        let errorHtml = '<ul>';
                        $.each(errors, function(key, value) {
                            errorHtml += '<li>' + value[0] + '</li>';
                        });
                        errorHtml += '</ul>';
                        $('#form-errors').html(errorHtml).show();
                    }
                });
            });
        });
    </script>

@endsection
