<?php

use App\Http\Controllers\EmpresaController;
use App\Http\Controllers\SucursalController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\AfiliadoController;
use App\Http\Controllers\ProveedorController;
use App\Http\Controllers\AlmacenController;
use App\Http\Controllers\CategoriaController;
use App\Http\Controllers\ProductoController;
use App\Http\Controllers\FacturaController;
use App\Http\Controllers\VendedorController;
use Illuminate\Support\Facades\Route;
use App\Http\Middleware\NoCache;

Route::get('/', function () {
    return view('auth.login');
})->middleware(['guest', NoCache::class]);;


Route::get('/dashboard', function () {
    return view('dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

    //Rutas Empresa
    Route::get('/empresa', [EmpresaController::class, 'index'])->name('empresa.index');
    Route::post('/empresa/store', [EmpresaController::class, 'store'])->name('empresa.store');
    Route::put('/empresa/{empresa}', [EmpresaController::class, 'update'])->name('empresa.update');

    //Rutas Sucursal
    Route::get('/sucursal', [SucursalController::class, 'index'])->name('sucursal.index');
    Route::post('/sucursal/store', [SucursalController::class, 'store'])->name('sucursal.store');
    Route::post('/sucursales/editar', [SucursalController::class, 'edit'])->name('sucursales.editar');
    Route::put('/sucursal/update', [SucursalController::class, 'update'])->name('sucursal.update');
    Route::get('/sucursales', [SucursalController::class, 'obtenerSucursales'])->name('sucursal.lista');
    Route::patch('/sucursales/cambiar-estatus/', [SucursalController::class, 'cambiarEstatus'])->name('sucursales.cambiarEstatus');
    Route::get('/sucursal/perfil/{sucursal}', [SucursalController::class, 'show'])->name('sucursal.show');
    Route::get('/sucursales/habilitadas', [SucursalController::class, 'obtenerSucursalesHabilitadas'])->name('sucursales.habilitadas');

    //Rutas Afiliados
    Route::get('/afiliado', [AfiliadoController::class, 'index'])->name('afiliado.index');
    Route::get('/afiliado/perfil/{idAfiliado}', [AfiliadoController::class, 'show'])->name('afiliado.show');
    Route::get('/afiliado/lista', [AfiliadoController::class, 'obtenerAfiliados'])->name('afiliado.lista');
    Route::post('/afiliado/store', [AfiliadoController::class, 'store'])->name('afiliado.store');
    Route::post('/afiliado/editar', [AfiliadoController::class, 'edit'])->name('afiliado.editar');
    Route::put('/afiliado/update', [AfiliadoController::class, 'update'])->name('afiliado.update');
    Route::patch('/afiliado/cambiarEstatus', [AfiliadoController::class, 'cambiarEstatus'])->name('afiliado.cambiarEstatus');


    //Rutas Proveedor
    Route::get('/proveedor', [ProveedorController::class, 'index'])->name('proveedor.index');
    Route::get('/proveedor/perfil/{idProveedor}', [ProveedorController::class, 'show'])->name('proveedor.show');
    Route::get('/proveedor/lista', [ProveedorController::class, 'obtenerProveedores'])->name('proveedor.lista');
    Route::post('/proveedor/store', [ProveedorController::class, 'store'])->name('proveedor.store');
    Route::post('/proveedor/editar', [ProveedorController::class, 'edit'])->name('proveedor.editar');
    Route::put('/proveedor/update', [ProveedorController::class, 'update'])->name('proveedor.update');
    Route::patch('/proveedor/cambiarEstatus', [ProveedorController::class, 'cambiarEstatus'])->name('proveedor.cambiarEstatus');


    //Rutas Vendedor
    Route::get('/vendedor', [VendedorController::class, 'index'])->name('vendedor.index');
    Route::get('/vendedor/perfil/{idVendedor}', [VendedorController::class, 'show'])->name('vendedor.show');
    Route::get('/vendedor/lista', [VendedorController::class, 'obtenerVendedores'])->name('vendedor.lista');
    Route::post('/vendedor/store', [VendedorController::class, 'store'])->name('vendedor.store');
    Route::post('/vendedor/editar', [VendedorController::class, 'edit'])->name('vendedor.editar');
    Route::put('/vendedor/update', [VendedorController::class, 'update'])->name('vendedor.update');
    Route::patch('/vendedor/cambiarEstatus', [VendedorController::class, 'cambiarEstatus'])->name('vendedor.cambiarEstatus');

    //Rutas Almacen
    Route::get('/almacen', [AlmacenController::class, 'index'])->name('almacen.index');
    Route::get('/almacen/perfil/{idAlmacen}', [AlmacenController::class, 'show'])->name('almacen.show');
    Route::get('/almacen/lista', [AlmacenController::class, 'obtenerAlmacenes'])->name('almacen.lista');
    Route::post('/almacen/store', [AlmacenController::class, 'store'])->name('almacen.store');
    Route::post('/almacen/editar', [AlmacenController::class, 'edit'])->name('almacen.editar');
    Route::put('/almacen/update', [AlmacenController::class, 'update'])->name('almacen.update');
    Route::patch('/almacen/cambiarEstatus', [AlmacenController::class, 'cambiarEstatus'])->name('almacen.cambiarEstatus');


    //Rutas Categoria
    Route::get('/categoria', [CategoriaController::class, 'index'])->name('categoria.index');
    Route::get('/categoria/{id}/subcategorias', [CategoriaController::class, 'getSubcategorias']);
    Route::get('/categoria/perfil/{idCategoria}', [CategoriaController::class, 'show'])->name('categoria.show');
    Route::get('/categoria/lista', [CategoriaController::class, 'obtenerCategorias'])->name('categoria.lista');
    Route::post('/categoria/store', [CategoriaController::class, 'store'])->name('categoria.store');
    Route::post('/categoria/store-subcategoria', [CategoriaController::class, 'storeSubCategoria'])->name('categoria.store-subcategoria');
    Route::post('/categoria/editar', [CategoriaController::class, 'edit'])->name('categoria.editar');
    Route::put('/categoria/update', [CategoriaController::class, 'update'])->name('categoria.update');
    Route::patch('/categoria/cambiarEstatus', [CategoriaController::class, 'cambiarEstatus'])->name('categoria.cambiarEstatus');

    //Rutas Producto
    Route::get('/producto', [ProductoController::class, 'index'])->name('producto.index');
    Route::get('/producto/perfil/{idProducto}', [ProductoController::class, 'show'])->name('producto.show');
    Route::get('/producto/lista', [ProductoController::class, 'obtenerProductos'])->name('producto.lista');
    Route::post('/producto/store', [ProductoController::class, 'store'])->name('producto.store');
    Route::post('/producto/editar', [ProductoController::class, 'edit'])->name('producto.editar');
    Route::put('/producto/update', [ProductoController::class, 'update'])->name('producto.update');
    Route::patch('/producto/cambiarEstatus', [ProductoController::class, 'cambiarEstatus'])->name('producto.cambiarEstatus');
    Route::post('/producto/upload', [ProductoController::class, 'upload'])->name('producto.upload');
    Route::post('/producto/deleteImage', [ProductoController::class, 'deleteImage'])->name('producto.deleteImage');
    Route::post('/producto/storeProductoEmpresa', [ProductoController::class, 'storeProductoEmpresa'])->name('producto.storeProductoEmpresa');

    //Rutas Factura

    Route::get('/factura/proveedor', [FacturaController::class, 'indexFacturaProveedor'])->name('factura.indexProveedor');
    Route::get('/factura/proveedor/create', [FacturaController::class, 'createFacturaProveedor'])->name('factura.createProveedor');
    Route::get('/factura/proveedor/getAfiliados', [FacturaController::class, 'getAfiliados'])->name('factura.getAfiliados');
    Route::get('/factura/proveedor/getEmpresa', [FacturaController::class, 'getEmpresa'])->name('factura.getEmpresa');
    Route::get('/factura/getProveedores', [FacturaController::class, 'getProveedores'])->name('factura.getProveedores');
    Route::get('/factura/getProductos/{proveedorId}', [FacturaController::class, 'getProductos'])->name('factura.getProductos');
    Route::post('/factura/proveedor/storeAfiliado', [FacturaController::class, 'storeFacturaProveedorAfiliado'])->name('factura.storeFacturaProveedorAfiliado');
    Route::post('/factura/proveedor/storeEmpresa', [FacturaController::class, 'storeFacturaProveedorEmpresa'])->name('factura.storeFacturaProveedorEmpresa');
    route::get('/factura/proveedor/listaFacturaEmpresa', [FacturaController::class, 'listaFacturaEmpresa'])->name('factura.listaFacturaEmpresa');
    route::get('/factura/proveedor/listaFacturaAfiliado', [FacturaController::class, 'listaFacturaAfiliado'])->name('factura.listaFacturaAfiliado');
});

require __DIR__ . '/auth.php';
